/*
 * Copyright 2015-2016 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.common.exception;

import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * Simple error handler that logs the error using a
 * {@link java.util.logging.Logger}. Exceptions are logged with a level of
 * <code>WARNING</code>, other errors are logged with a level of
 * <code>INFO</code>. The logger is retrieved by getting a logger with the name
 * of the calling class.
 * 
 * @author Sebastian Marsching
 */
public class JavaUtilLoggingErrorHandler implements ErrorHandler {

    /**
     * Default constructor. This constructor does not do anything because this
     * class does not have any state.
     */
    public JavaUtilLoggingErrorHandler() {
    }

    @Override
    public void handleError(Class<?> context, Throwable e, String description) {
        Logger logger = Logger.getLogger(context.getName());
        if (e != null) {
            logger.log(Level.WARNING, description != null ? description
                    : "Caught an exception.", e);
        } else {
            logger.log(Level.INFO, description);
        }
    }

}
